#!/usr/bin/env python3

import csv
from fpdf import FPDF

from importlib.resources import path


class Translator:
    def __init__(self):
        self.dict_file = path('data.symbols', 'sun_dictionary.csv')
        self.font_path = path('data.fonts', 'SUN7_8_1210.ttf')
        self.sun_symbols = self.create_dict(self.dict_file)

    def create_dict(self, dict_file):

        sun_dict = {}
        with open(dict_file) as file:
            reader = csv.reader(file)
            for row in reader:
                sun_dict[row[0]] = row[1]

        return sun_dict

    def translateText(self, text):

        string_translated = []
        no_translation = []

        for word in text.split():
            if word in self.sun_symbols:
                string_translated.append(self.sun_symbols[word])
            else:
                word_capitalized = word.capitalize()
                word_lower = word.lower()
                if word_capitalized in self.sun_symbols:
                    string_translated.append(self.sun_symbols[word_capitalized])
                elif word_lower in self.sun_symbols:
                    string_translated.append(self.sun_symbols[word_lower])
                else:
                    no_translation.append(word)

        translated = (' '.join(string_translated))
        return translated

    def saveToPdf(self, text, save_file):
        pdf = FPDF(format="letter", unit="in")
        pdf.add_font(
            'SUN7_8_1210', '',
            # fname='/home/carl/.local/share/fonts/keyman/sun7_8_1210/SUN7_8_1210.ttf')
            fname=self.font_path)
        pdf.set_font('SUN7_8_1210', '', size=14)
        pdf.add_page()
        pdf.write(txt=text)
        pdf.output(save_file)



#!/usr/bin/env python3

import tkinter as tk
from tkinter import ttk
from tkinter import filedialog

# from importlib.resources import read_text

# contents = read_text('symbols', 'sun_dictionary.csv')
# print(contents)

from translator.translate import Translator
from gui.menubar import Menubar

sun_font = ("SUN7_8_1210", 16)


class Application(ttk.Frame):
    def __init__(self, master=None):
        tk.Frame.__init__(self, master)
        self.grid(sticky=tk.N+tk.S+tk.E+tk.W)
        # self.grid(sticky=tk.NSEW)
        self.createWidgets()
        self.translator = Translator()

    def createWidgets(self):
        top = self.winfo_toplevel()
        top.rowconfigure(0, weight=1, minsize=200)
        top.columnconfigure(0, weight=1, minsize=200)

        self.rowconfigure(0, weight=1)
        self.rowconfigure(1, weight=1)
        self.rowconfigure(2, weight=1)
        self.columnconfigure(0, weight=1)
        self.columnconfigure(1, weight=1)

        self.menubar = Menubar(self, top)

        self.textEntry = tk.Text(self)
        self.textEntry.grid(row=0, column=0,
                            sticky=tk.N+tk.S+tk.E+tk.W)
        self.textEntry.configure(font=("Times", 16),
                                 wrap=tk.WORD)

        self.textEntry2 = tk.Text(self)
        self.textEntry2.grid(row=0, column=1,
                             sticky=tk.N+tk.S+tk.E+tk.W)
        self.textEntry2.configure(font=sun_font,
                                  wrap=tk.WORD)
        self.textEntry2.configure(state=tk.DISABLED)

        self.translateButton = ttk.Button(self, text="Translate",
                                          command=self.translate)
        self.translateButton.grid(row=1, column=0, columnspan=2,
                                  sticky=tk.N+tk.S+tk.E+tk.W)

        self.saveButton = ttk.Button(self, text="Save",
                                     command=self.save)
        self.saveButton.grid(row=2, column=0, columnspan=2,
                             sticky=tk.N+tk.S+tk.E+tk.W)

        self.textEntry.bind("<Return>", self.__translate)

    def __translate(self, event):
        self.translateButton.invoke()

    def translate(self):
        text = self.textEntry.get('1.0', 'end')

        translated = self.translator.translateText(text)

        self.textEntry2.configure(state=tk.NORMAL)
        self.textEntry2.delete('1.0', 'end')
        self.textEntry2.insert('1.0', translated)
        self.textEntry2.configure(state=tk.DISABLED)

    def save(self):
        filename = filedialog.asksaveasfilename(filetypes=[("PDF", "*.pdf")],
                                                defaultextension='.pdf',
                                                title="Save As")
        text = self.textEntry2.get('1.0', 'end')
        self.translator.saveToPdf(text, filename)


def main():
    app = Application()
    app.master.title("Sun Translation")
    app.mainloop()


if __name__ == "__main__":
    main()



#!/usr/bin/env python3

import tkinter as tk


class Menubar:
    def __init__(self, root, top):
        root.menubar = tk.Menu(top)
        top.config(menu=root.menubar)

        root.file = tk.Menu(root.menubar, tearoff=0)
        root.edit = tk.Menu(root.menubar, tearoff=0)
        root.tools = tk.Menu(root.menubar, tearoff=0)
        root.help_ = tk.Menu(root.menubar, tearoff=0)

        root.menubar.add_cascade(menu=root.file, label="File")
        root.menubar.add_cascade(menu=root.edit, label="Edit")
        root.menubar.add_cascade(menu=root.tools, label="Tools")
        root.menubar.add_cascade(menu=root.help_, label="Help")

        root.file.add_command(label="New")
        root.file.add_command(label="Save", command=root.save)
        root.file.add_command(label="Quit", command=root.quit)

        root.tools.add_command(label="Translate", command=root.translate)
